"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stagedConfig = exports.staged = exports.diffConfig = exports.diff = void 0;
const git_1 = require("./git");
const STAGED = true;
const isLineWithinRange = (line) => (range) => range.isWithinRange(line);
const diff = {
    postprocess: (messages, filename) => {
        const isFilenameExcluded = !git_1.getDiffFileList().includes(filename);
        if (isFilenameExcluded) {
            return [];
        }
        return messages
            .map((message) => {
            const filteredMessage = message.filter(({ fatal, line }) => {
                if (fatal === true) {
                    return true;
                }
                const isLineWithinSomeRange = git_1.getRangesForDiff(git_1.getDiffForFile(filename)).some(isLineWithinRange(line));
                return isLineWithinSomeRange;
            });
            return filteredMessage;
        })
            .reduce((a, b) => a.concat(b), []);
    },
    supportsAutofix: true,
};
exports.diff = diff;
const diffConfig = {
    plugins: ["diff"],
    overrides: [
        {
            files: ["*"],
            processor: "diff/diff",
        },
    ],
    ignorePatterns: git_1.getIgnorePatterns(),
};
exports.diffConfig = diffConfig;
const staged = {
    postprocess: (messages, filename) => {
        const isFilenameExcluded = !git_1.getDiffFileList().includes(filename);
        if (isFilenameExcluded) {
            return [];
        }
        return messages
            .map((message) => {
            const filteredMessage = message.filter(({ fatal, line }) => {
                if (fatal === true) {
                    return true;
                }
                const isLineWithinSomeRange = git_1.getRangesForDiff(git_1.getDiffForFile(filename, STAGED)).some(isLineWithinRange(line));
                return isLineWithinSomeRange;
            });
            return filteredMessage;
        })
            .reduce((a, b) => a.concat(b), []);
    },
    supportsAutofix: true,
};
exports.staged = staged;
const stagedConfig = {
    plugins: ["diff"],
    overrides: [
        {
            files: ["*"],
            processor: "diff/staged",
        },
    ],
    ignorePatterns: git_1.getIgnorePatterns(STAGED),
};
exports.stagedConfig = stagedConfig;
